module Tests where

import Data.Maybe(isJust, isNothing, fromJust)
import Test.Tasty
import Test.Tasty.HUnit

import Date

import BBook

run = defaultMain $ testGroup "All tests" [dTests, bTests]

dTests = testGroup "Date tests" 
  [ testCase "Valid date" $
    assertBool "Should be valid" (isJust (date 31 3 1985))
  , testCase "Invalid date" $
    assertBool "Should be invalid" $ isNothing (date 29 2 1983)
  , testCase "Show date" $
    "23.03.0786" @=? show (fromJust (date 23 3 786))
  , testCase "Order on dates (1)" $
    assertBool "Should be true" $ date 15 1 1985 <= date 16 1 1985
  , testCase "Order on dates (2)" $
    assertBool "Should be true" $ not (date 1 9 1985 <= date 11 7 1985)
  ]

bTests = testGroup "Birthday book tests" 
  [ testCase "Geburtstag Tanja Eckhorst" $
    date 13 1 1985 @=? getBirthday b5 "Tanja Eckhorst"
  , testCase "Geburtstag Horst Schultz" $
    date 25 10 1984 @=? getBirthday b5 "Horst Schultz"
  , testCase "Geburtstage" $
    ["Horst Schultz", "Tanja Eckhorst"] @=?
    getNamesBetween b5 (fromJust (date 1 6 1984)) (fromJust (date 28 02 1985))
  , testCase "Nächster Geburtstag" $
     Just("Tanja Eckhorst", fromJust (date 13 1 1985)) @=? nextBirthday b5 (fromJust (date 1 1 1985))
  ]

b5 :: BBook
b5 = let Just b1 = addEntry newBook "Hans Meier" 27 3 1984
         Just b2 = addEntry b1 "Horst Schultz" 25 9 1985
         Just b3 = addEntry b2 "Tanja Eckhorst" 13 1 1985
         Just b4 = addEntry b3 "Markus Felderding" 8 8 1985
         Just b5 = addEntry b4 "Horst Schultz" 25 10 1984
     in b5
